@@ -3,23 +3,23 @@ from nonebot import on_command
 from nonebot.matcher import Matcher
 from nonebot.typing import T_Handler
 from nonebot.params import CommandArg
+from nonebot.plugin import PluginMetadata
 from nonebot.adapters.onebot.v11 import Message
 from nonebot.log import logger
 
 from .data_source import sources, Source
 
-
-__help__plugin_name__ = "music"
-__des__ = "点歌"
-__cmd__ = """
-点歌/qq点歌/网易点歌/酷我点歌/酷狗点歌/咪咕点歌/b站点歌 {keyword}
-默认为qq点歌
-""".strip()
-__short_cmd__ = "点歌 {keyword}"
-__example__ = """
-点歌 万古生香
-""".strip()
-__usage__ = f"{__des__}\nUsage:\n{__cmd__}\nExample:\n{__example__}"
+__plugin_meta__ = PluginMetadata(
+    name="点歌",
+    description="点歌，默认为qq点歌，支持qq、网易、酷我、酷狗、咪咕、b站音频区",
+    usage="点歌/qq点歌/网易点歌/酷我点歌/酷狗点歌/咪咕点歌/b站点歌 + 关键词",
+    extra={
+        "unique_name": "simplemusic",
+        "example": "点歌 万古生香",
+        "author": "meetwq <meetwq@gmail.com>",
+        "version": "0.1.2",
+    },
+)
 
 
 def create_matchers():
